@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2158 $
- * $Id: ExceptionListFactory.class.php 2158 2008-09-15 23:26:15Z ipso $
- * $Date: 2008-09-15 16:26:15 -0700 (Mon, 15 Sep 2008) $
+ * $Revision: 2376 $
+ * $Id: ExceptionListFactory.class.php 2376 2009-01-23 17:12:17Z ipso $
+ * $Date: 2009-01-23 09:12:17 -0800 (Fri, 23 Jan 2009) $
  */
 
 /**
@@ -582,7 +582,7 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 					'end_date' => $this->db->BindDate( $end_date ),
 					);
 
-		if ( $this->db->dataProvider == 'mysql' ) {
+		if ( strncmp($this->db->databaseType,'mysql',5) == 0 ) {
 			$dow_sql = '(dayofweek( b.date_stamp)-1)';
 		} else {
 			$dow_sql = '(date_part(\'DOW\', b.date_stamp))';
