@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: Factory.class.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 2426 $
+ * $Id: Factory.class.php 2426 2009-02-18 22:39:19Z ipso $
+ * $Date: 2009-02-18 14:39:19 -0800 (Wed, 18 Feb 2009) $
  */
 
 /**
@@ -202,7 +202,7 @@ abstract class Factory {
 
 	function getCreatedDate() {
 		if ( isset($this->data['created_date']) ) {
-			return $this->data['created_date'];
+			return (int)$this->data['created_date'];
 		}
 
 		return FALSE;
@@ -291,7 +291,7 @@ abstract class Factory {
 	}
 	function getUpdatedBy() {
 		if ( isset($this->data['updated_by']) ) {
-			return $this->data['updated_by'];
+			return (int)$this->data['updated_by'];
 		}
 
 		return FALSE;
