@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2158 $
- * $Id: Permission.class.php 2158 2008-09-15 23:26:15Z ipso $
- * $Date: 2008-09-15 16:26:15 -0700 (Mon, 15 Sep 2008) $
+ * $Revision: 2426 $
+ * $Id: Permission.class.php 2426 2009-02-18 22:39:19Z ipso $
+ * $Date: 2009-02-18 14:39:19 -0800 (Wed, 18 Feb 2009) $
  */
 
 /**
@@ -41,8 +41,12 @@ class Permission {
 			$plf->getAllPermissionsByCompanyIdAndUserId( $company_id, $user_id );
 			if ( $plf->getRecordCount() > 0 ) {
 				//Debug::Text('Found Permissions in DB!', __FILE__, __LINE__, __METHOD__,9);
+				$perm_arr['_system']['last_updated_date'] = NULL;
 				foreach($plf as $p_obj) {
 					//Debug::Text('Perm -  Section: '. $p_obj->getSection(), __FILE__, __LINE__, __METHOD__,9);
+					if ( $p_obj->getUpdatedDate() > $perm_arr['_system']['last_updated_date'] ) {
+						$perm_arr['_system']['last_updated_date'] =  $p_obj->getUpdatedDate();
+					}
 					$perm_arr[$p_obj->getSection()][$p_obj->getName()] = $p_obj->getValue();
 				}
 
@@ -86,13 +90,22 @@ class Permission {
 	}
 
 	function Redirect($result) {
-		if ($result !== TRUE) {
+		if ( $result !== TRUE ) {
 			Redirect::Page( URLBuilder::getURL( NULL, Environment::getBaseURL().'/permission/PermissionDenied.php') );
 		}
 
 		return TRUE;
 	}
 
+	function PermissionDenied( $result = FALSE, $description = 'Permission Denied' ) {
+		if ( $result !== TRUE ) {
+			Debug::Text('Permission Denied! Description: '. $description, __FILE__, __LINE__, __METHOD__, 10);
+			return APIFactory::returnHandler( FALSE, 'PERMISSION', $description );
+		}
+
+		return TRUE;
+	}
+
 	function Query($section, $name, $user_id = NULL, $company_id = NULL) {
 		Debug::Text('Permission Query!' , __FILE__, __LINE__, __METHOD__,9);
 		if ( $user_id == NULL OR $user_id == '') {
@@ -141,5 +154,31 @@ class Permission {
 
 		return FALSE;
 	}
+
+	function getLastUpdatedDate( $user_id = NULL, $company_id = NULL ) {
+		//Use Cache_Lite class once we need performance.
+		if ( $user_id == NULL OR $user_id == '') {
+			global $current_user;
+			if ( isset($current_user) ) {
+				$user_id = $current_user->getId();
+			} else {
+				return FALSE;
+			}
+		}
+
+		if ( $company_id == NULL OR $company_id == '') {
+			global $current_company;
+			$company_id = $current_company->getId();
+		}
+
+		//Debug::Text('Permission Check - Section: '. $section .' Name: '. $name .' User ID: '. $user_id .' Company ID: '. $company_id, __FILE__, __LINE__, __METHOD__,9);
+		$permission_arr = $this->getPermissions( $user_id, $company_id );
+
+		if ( isset($permission_arr['_system']['last_updated_date']) ) {
+			return $permission_arr['_system']['last_updated_date'];
+		}
+
+		return FALSE;
+	}
 }
 ?>
