@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: StationFactory.class.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 2570 $
+ * $Id: StationFactory.class.php 2570 2009-05-28 21:29:33Z ipso $
+ * $Date: 2009-05-28 14:29:33 -0700 (Thu, 28 May 2009) $
  */
 include_once('Net/IPv4.php');
 
@@ -105,6 +105,9 @@ class StationFactory extends Factory {
 										21600 => TTi18n::gettext('6 Hours'),
 										43200 => TTi18n::gettext('12 Hours'),
 										86400 => TTi18n::gettext('24 Hours'),
+										172800 => TTi18n::gettext('48 Hours'),
+										259200 => TTi18n::gettext('72 Hours'),
+										604800 => TTi18n::gettext('1 Week'),
 									);
 				break;
 			case 'push_frequency':
@@ -121,6 +124,9 @@ class StationFactory extends Factory {
 										21600 => TTi18n::gettext('6 Hours'),
 										43200 => TTi18n::gettext('12 Hours'),
 										86400 => TTi18n::gettext('24 Hours'),
+										172800 => TTi18n::gettext('48 Hours'),
+										259200 => TTi18n::gettext('72 Hours'),
+										604800 => TTi18n::gettext('1 Week'),
 									);
 				break;
 			case 'time_clock_command':
