@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: TTDate.class.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 2453 $
+ * $Id: TTDate.class.php 2453 2009-03-20 16:34:04Z ipso $
+ * $Date: 2009-03-20 09:34:04 -0700 (Fri, 20 Mar 2009) $
  */
 
 /**
@@ -94,12 +94,18 @@ class TTDate {
 		return self::$time_zone;
 	}
 	public static function setTimeZone($time_zone = NULL) {
+		global $config_vars;
+
 		$time_zone = Misc::trimSortPrefix( trim($time_zone) );
 
 		//Default to system local timezone if no timezone is specified.
 		if ( $time_zone == '' ) {
-			//$time_zone = 'GMT';
-			$time_zone = date('e');
+			if ( isset($config_vars['other']['system_timezone']) ) {
+				$time_zone = $config_vars['other']['system_timezone'];
+			} else {
+				//$time_zone = 'GMT';
+				$time_zone = date('e');
+			}
 		}
 
 		if ( $time_zone == self::$time_zone ) {
@@ -115,7 +121,7 @@ class TTDate {
 			putenv('TZ='.$time_zone);
 
 			global $db;
-			if ( isset($db) AND is_object($db) AND $db->dataProvider == 'mysql' ) {
+			if ( isset($db) AND is_object($db) AND strncmp($db->databaseType,'mysql',5) == 0 ) {
 				if ( @$db->Execute('SET SESSION time_zone=\''. $time_zone .'\'') == FALSE ) {
 					return FALSE;
 				}
@@ -231,8 +237,9 @@ class TTDate {
 		*/
 		//Get rid of any spaces or commas.
 		//ie: 1,100 :10 should still parse correctly
-		$time_unit = str_replace( array(',',' '), '', $time_unit);
-		Debug::text('Time Unit Format: '. self::$time_unit_format, __FILE__, __LINE__, __METHOD__, 10);
+		$time_unit = trim( str_replace( array(',',' '), '', $time_unit) );
+		//Debug::text('Time Unit: '. $time_unit, __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('Time Unit Format: '. self::$time_unit_format, __FILE__, __LINE__, __METHOD__, 10);
 
 		//Convert string to seconds.
 		switch (self::$time_unit_format) {
@@ -250,7 +257,8 @@ class TTDate {
 					$time_units[2] = 0;
 				}
 
-				if ( $time_units[0] < 0 OR $time_units[1] < 0 OR $time_units[2] < 0) {
+				//Check if the first character is '-', or thre are any negative integers.
+				if ( strncmp($time_units[0],'-',1) == 0 OR $time_units[0] < 0 OR $time_units[1] < 0 OR $time_units[2] < 0) {
 					$negative_number = TRUE;
 				}
 
@@ -583,8 +591,8 @@ class TTDate {
 		return self::$month_of_year_arr;
 	}
 
-	public static function getDayOfWeekArray() {
-		if ( is_array(self::$day_of_week_arr) == FALSE ) {
+	public static function getDayOfWeekArray( $translation = TRUE ) {
+		if ( $translation == TRUE AND is_array(self::$day_of_week_arr) == FALSE ) {
 			self::$day_of_week_arr = array(
 											0 => TTi18n::gettext('Sunday'),
 											1 => TTi18n::gettext('Monday'),
@@ -594,7 +602,18 @@ class TTDate {
 											5 => TTi18n::gettext('Friday'),
 											6 => TTi18n::gettext('Saturday')
 				);
-	        }
+	    } else {
+			//Translated days of week can't be piped back into strtotime() for parsing.
+			self::$day_of_week_arr = array(
+											0 => 'Sunday',
+											1 => 'Monday',
+											2 => 'Tuesday',
+											3 => 'Wednesday',
+											4 => 'Thursday',
+											5 => 'Friday',
+											6 => 'Saturday'
+				);
+		}
 		return self::$day_of_week_arr;
 	}
 
@@ -612,8 +631,8 @@ class TTDate {
 		}
 	}
 
-	public static function getDayOfWeekByInt($int) {
-		self::getDayOfWeekArray();
+	public static function getDayOfWeekByInt($int, $translation = TRUE ) {
+		self::getDayOfWeekArray( TRUE );
 
 		if ( isset(self::$day_of_week_arr[$int]) ) {
 			return self::$day_of_week_arr[$int];
@@ -1198,7 +1217,7 @@ class TTDate {
 		return $retval;
 	}
 
-	public static function getWeek( $epoch = NULL, $start_day_of_week = 1 ) {
+	public static function getWeek( $epoch = NULL, $start_day_of_week = 0 ) {
 		//Default start_day_of_week to 1 (Monday) as that is what PHP defaults to.
 		if ($epoch == NULL OR $epoch == '') {
 			$epoch = self::getTime();
