@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: PayPeriodScheduleFactory.class.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 2453 $
+ * $Id: PayPeriodScheduleFactory.class.php 2453 2009-03-20 16:34:04Z ipso $
+ * $Date: 2009-03-20 09:34:04 -0700 (Fri, 20 Mar 2009) $
  */
 
 /**
@@ -722,7 +722,7 @@ class PayPeriodScheduleFactory extends Factory {
 				if ( $last_pay_period_end_day_of_week != $this->getStartDayOfWeek() ) {
 					Debug::text('zTmp Pay Period End Date: '. 'next '. TTDate::getDayOfWeekByInt( $this->getStartDayOfWeek() ), __FILE__, __LINE__, __METHOD__, 10);
 					//$tmp_pay_period_end_date = strtotime('next '. TTDate::getDayOfWeekByInt( $this->getStartDayOfWeek() ), $last_pay_period_end_date )-1;
-					$tmp_pay_period_end_date = strtotime('next '. TTDate::getDayOfWeekByInt( $this->getStartDayOfWeek() ), $last_pay_period_end_date );
+					$tmp_pay_period_end_date = strtotime('next '. TTDate::getDayOfWeekByInt( $this->getStartDayOfWeek(), FALSE ), $last_pay_period_end_date );
 
 					//strtotime doesn't keep time when using "next", it resets it to midnight on the day, so we need to adjust for that.
 					$tmp_pay_period_end_date = TTDate::getTimeLockedDate( TTDate::getBeginDayEpoch($tmp_pay_period_end_date) + $this->getDayStartTime(), $tmp_pay_period_end_date)-1;
@@ -910,6 +910,8 @@ class PayPeriodScheduleFactory extends Factory {
 		Debug::text('End Date ('. $end_date.'): '. TTDate::getDate('DATE+TIME', $end_date ), __FILE__, __LINE__, __METHOD__,10);
 
 		$this->getNextPayPeriod($end_date);
+		var_dump( $this );
+		Debug::Display();
 
 		Debug::text('Next pay period starts: '. TTDate::getDate('DATE+TIME', $this->getNextStartDate() ), __FILE__, __LINE__, __METHOD__,10);
 
@@ -932,25 +934,6 @@ class PayPeriodScheduleFactory extends Factory {
 				Debug::text('New Pay Period ID: '. $new_pay_period_id, __FILE__, __LINE__, __METHOD__,10);
 
 				if ( $new_pay_period_id != '' ) {
-					/*
-					//
-					//Handle this in PayPeriodFactory now.
-					//
-					//Check for any user_date rows in this time period that are not assigned to a pay period.
-					//Get all users assigned to this pp schedule
-					$udlf = new UserDateListFactory();
-					$udlf->getByUserIdAndStartDateAndEndDateAndEmptyPayPeriod( $this->getUser(), $this->getNextStartDate(), $this->getNextEndDate() );
-					Debug::text(' New Pay Period ID: '. $new_pay_period_id .' Pay Period orphaned User Date Rows: '. $udlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
-					if ( $udlf->getRecordCount() > 0 ) {
-						foreach( $udlf as $ud_obj ) {
-							$ud_obj->setPayPeriod( $new_pay_period_id );
-							if ( $ud_obj->isValid() ) {
-								$ud_obj->Save();
-							}
-						}
-					}
-					*/
-
 					$this->setOriginalTimeZone();
 
 					return TRUE;
@@ -1019,6 +1002,9 @@ class PayPeriodScheduleFactory extends Factory {
 		return FALSE;
 	}
 
+	//Pay period number functionality is deprecated, it causes too many problems
+	//for little or no benefit. Its also impossible to properly handle in custom situations where pay periods
+	//may be adjusted.
 	function getCurrentPayPeriodNumber($epoch = NULL, $end_date_epoch = NULL) {
 		//EPOCH MUST BE TRANSACTION DATE!!!
 		//End Date Epoch must be END DATE of pay period
