@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: PremiumPolicyFactory.class.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 2338 $
+ * $Id: PremiumPolicyFactory.class.php 2338 2009-01-14 21:32:59Z ipso $
+ * $Date: 2009-01-14 13:32:59 -0800 (Wed, 14 Jan 2009) $
  */
 
 /**
@@ -1369,16 +1369,21 @@ class PremiumPolicyFactory extends Factory {
 
 			Debug::text(' Raw Start TimeStamp('.$this->getStartTime(TRUE).'): '. TTDate::getDate('DATE+TIME', $this->getStartTime() ) .' Raw End TimeStamp: '. TTDate::getDate('DATE+TIME', $this->getEndTime() )  , __FILE__, __LINE__, __METHOD__, 10);
 			$start_time_stamp = TTDate::getTimeLockedDate( $this->getStartTime(), $in_epoch);
-			$end_time_stamp = TTDate::getTimeLockedDate( $this->getEndTime(), $out_epoch);
+			$end_time_stamp = TTDate::getTimeLockedDate( $this->getEndTime(), $in_epoch);
 
 			//Check if end timestamp is before start, if it is, move end timestamp to next day.
 			if ( $end_time_stamp < $start_time_stamp ) {
 				Debug::text(' Moving End TimeStamp to next day.', __FILE__, __LINE__, __METHOD__, 10);
 				$end_time_stamp = $end_time_stamp + 86400;
 			}
-			Debug::text(' Start TimeStamp: '. TTDate::getDate('DATE+TIME', $start_time_stamp) .' End TimeStamp: '. TTDate::getDate('DATE+TIME', $end_time_stamp)  , __FILE__, __LINE__, __METHOD__, 10);
 
-			$retval = TTDate::getTimeOverLapDifference( $start_time_stamp, $end_time_stamp, $in_epoch, $out_epoch );
+			$start_time_stamp2 = $start_time_stamp - 86400;
+			$end_time_stamp2 = $end_time_stamp - 86400;
+
+			Debug::text(' Start TimeStamp: '. TTDate::getDate('DATE+TIME', $start_time_stamp) .' End TimeStamp: '. TTDate::getDate('DATE+TIME', $end_time_stamp)  , __FILE__, __LINE__, __METHOD__, 10);
+			Debug::text(' Start TimeStamp2: '. TTDate::getDate('DATE+TIME', $start_time_stamp2) .' End TimeStamp2: '. TTDate::getDate('DATE+TIME', $end_time_stamp2)  , __FILE__, __LINE__, __METHOD__, 10);
+
+			$retval = TTDate::getTimeOverLapDifference( $start_time_stamp, $end_time_stamp, $in_epoch, $out_epoch ) + TTDate::getTimeOverLapDifference( $start_time_stamp2, $end_time_stamp2, $in_epoch, $out_epoch );
 		}
 
 		Debug::text(' Partial Punch Total Time : '. $retval, __FILE__, __LINE__, __METHOD__, 10);
@@ -1391,14 +1396,21 @@ class PremiumPolicyFactory extends Factory {
 
 		Debug::text(' Raw Start TimeStamp('.$this->getStartTime(TRUE).'): '. TTDate::getDate('DATE+TIME', $this->getStartTime() ) .' Raw End TimeStamp: '. TTDate::getDate('DATE+TIME', $this->getEndTime() )  , __FILE__, __LINE__, __METHOD__, 10);
 		$start_time_stamp = TTDate::getTimeLockedDate( $this->getStartTime(), $in_epoch);
-		$end_time_stamp = TTDate::getTimeLockedDate( $this->getEndTime(), $out_epoch);
+		$end_time_stamp = TTDate::getTimeLockedDate( $this->getEndTime(), $in_epoch);
 
 		//Check if end timestamp is before start, if it is, move end timestamp to next day.
 		if ( $end_time_stamp < $start_time_stamp ) {
 			Debug::text(' Moving End TimeStamp to next day.', __FILE__, __LINE__, __METHOD__, 10);
 			$end_time_stamp = $end_time_stamp + 86400;
 		}
+
+		//If the premium policy start/end time spans midnight, there could be two windows in a single day
+		//where the premium policy applies, make sure we check both windows.
+		$start_time_stamp2 = $start_time_stamp - 86400;
+		$end_time_stamp2 = $end_time_stamp - 86400;
+
 		Debug::text(' Start TimeStamp: '. TTDate::getDate('DATE+TIME', $start_time_stamp) .' End TimeStamp: '. TTDate::getDate('DATE+TIME', $end_time_stamp)  , __FILE__, __LINE__, __METHOD__, 10);
+		Debug::text(' Start TimeStamp2: '. TTDate::getDate('DATE+TIME', $start_time_stamp2) .' End TimeStamp2: '. TTDate::getDate('DATE+TIME', $end_time_stamp2)  , __FILE__, __LINE__, __METHOD__, 10);
 
 		//Check to see if start/end time stamps are not set or are equal, we always return TRUE if they are.
 		if ( $start_time_stamp == ''
@@ -1409,13 +1421,14 @@ class PremiumPolicyFactory extends Factory {
 			return TRUE;
 		} else {
 			if ( $this->getIncludePartialPunch() == TRUE ) {
-				if ( ( $in_epoch >= $start_time_stamp AND $in_epoch <= $end_time_stamp )
-						OR ( $out_epoch >= $start_time_stamp AND $out_epoch <= $end_time_stamp ) ) {
+				if ( ( ( $in_epoch >= $start_time_stamp AND $in_epoch <= $end_time_stamp ) OR ( $out_epoch >= $start_time_stamp AND $out_epoch <= $end_time_stamp ) )
+						OR ( ( $in_epoch >= $start_time_stamp2 AND $in_epoch <= $end_time_stamp2 ) OR ( $out_epoch >= $start_time_stamp2 AND $out_epoch <= $end_time_stamp2 ) ) ) {
 					Debug::text(' Partial Punch Within Active Time!', __FILE__, __LINE__, __METHOD__, 10);
 					return TRUE;
 				}
 			} else {
-				if ( $in_epoch >= $start_time_stamp AND $in_epoch <= $end_time_stamp ) {
+				if ( ( $in_epoch >= $start_time_stamp AND $in_epoch <= $end_time_stamp )
+						OR ( $in_epoch >= $start_time_stamp2 AND $in_epoch <= $end_time_stamp2 ) ) {
 					Debug::text(' Within Active Time!', __FILE__, __LINE__, __METHOD__, 10);
 					return TRUE;
 				}
