@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: PunchControlFactory.class.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 2338 $
+ * $Id: PunchControlFactory.class.php 2338 2009-01-14 21:32:59Z ipso $
+ * $Date: 2009-01-14 13:32:59 -0800 (Wed, 14 Jan 2009) $
  */
 
 /**
@@ -638,65 +638,7 @@ class PunchControlFactory extends Factory {
 
 		return FALSE;
 	}
-/*
-	function calcAutoDeductMealPolicyTime( $total_time, $schedule_obj) {
 
-		****THIS IS HANDLED IN UserDateTotal FACTORY NOW****
-		If users are transferring branches/departs, autodeducts are no longer working.
-		But if they are transferring, why just punch out for lunch?
-		Auto-Deduct has many issues, especially when it comes to job costing.
-		 Several Solutions:
-		 	1. Just deduct the meal policy amount from the total per day. This will make it so each punch pair
-		 	total doesn't match the day total time, however this will cause all sorts of weirdness, and is probably
-		 	extremely bad idea.
-
-		 	2. Deduct time from each punch pair based on percentage of total time of the day? The problem with this
-		 	is we don't know when the end of the day is, so we have to wait 24hrs at least to even calculate it.
-
-			3. Add new "hour type" that either adds or subjects time from the total per day. This way
-			it can be separated out in the TimeSheet is well, ie:
-			Auto-Deduct: 30min
-			Auto-Include: 30min
-
-
-		$amount = 0;
-		$meal_policy_id = NULL;
-		Debug::text('Total Time: '. $total_time, __FILE__, __LINE__, __METHOD__, 10);
-
-		if ( is_object($schedule_obj) AND is_object($schedule_obj->getSchedulePolicyObject() ) ) {
-			Debug::text('Passed Schedule Obj: ', __FILE__, __LINE__, __METHOD__, 10);
-			if ( is_object($schedule_obj->getSchedulePolicyObject()->getMealPolicyObject() )
-					AND $schedule_obj->getSchedulePolicyObject()->getMealPolicyObject()->getType() == 10 ) {
-				Debug::text('Found Scheduled Auto-Deduct Meal Policy: '. $schedule_obj->getSchedulePolicyObject()->getMealPolicyObject()->getId(), __FILE__, __LINE__, __METHOD__, 10);
-
-				if ( $total_time > $schedule_obj->getSchedulePolicyObject()->getMealPolicyObject()->getTriggerTime() ) {
-					$meal_policy_id = $schedule_obj->getSchedulePolicyObject()->getMealPolicyObject()->getId();
-					$amount = $schedule_obj->getSchedulePolicyObject()->getMealPolicyObject()->getAmount();
-				}
-			}
-		} else {
-			Debug::text('NOT Passed Schedule Obj: ', __FILE__, __LINE__, __METHOD__, 10);
-			$mplf = new MealPolicyListFactory();
-			$mplf->getByPolicyGroupUserId( $this->getUserDateObject()->getUser() );
-			if ( $mplf->getRecordCount() == 1 ) {
-				$mp_obj = $mplf->getCurrent();
-				Debug::text('Found Meal Policy: '. $mp_obj->getId(), __FILE__, __LINE__, __METHOD__, 10);
-
-				if ( $mp_obj->getType() == 10 ) {
-					Debug::text('Found Auto-Deduct Meal Policy: '. $mp_obj->getId(), __FILE__, __LINE__, __METHOD__, 10);
-
-					if ( $total_time > $mp_obj->getTriggerTime() ) {
-						$meal_policy_id = $mp_obj->getId();
-						$amount = $mp_obj->getAmount();
-					}
-				}
-			}
-		}
-
-		Debug::text('AutoDeduct Meal Policy Amount: '. $amount, __FILE__, __LINE__, __METHOD__, 10);
-		return array('amount' => $amount, 'meal_policy_id' => $meal_policy_id);
-	}
-*/
 	function calcTotalTime() {
 		$plf = new PunchListFactory();
 		$plf->getByPunchControlId( $this->getId() );
@@ -734,15 +676,6 @@ class PunchControlFactory extends Factory {
 
 			if ( isset($total_time) ) {
 				Debug::text(' Setting TotalTime...', __FILE__, __LINE__, __METHOD__,10);
-				/*
-				//This is handled in UserDateTotal factory now.
-				//Check for AutoDeduct Meal Policy
-				$meal_auto_deduct_arr = $this->calcAutoDeductMealPolicyTime( $total_time, $schedule_obj );
-
-				$this->setTotalTime( $total_time - $meal_auto_deduct_arr['amount'] );
-				$this->setActualTotalTime( $actual_total_time - $meal_auto_deduct_arr['amount'] );
-				$this->setMealPolicyID( $meal_auto_deduct_arr['meal_policy_id'] );
-				*/
 
 				$this->setTotalTime( $total_time);
 				$this->setActualTotalTime( $actual_total_time);
@@ -760,36 +693,6 @@ class PunchControlFactory extends Factory {
 		return FALSE;
 	}
 
-/*
-	function calcUserDateTotalTime() {
-
-		//Add a row to the user date total table, as "worked" hours.
-		//Edit if it already exists and is not set as override.
-		$udtlf = new UserDateTotalListFactory();
-		$udtlf->getByUserDateIdAndPunchControlId( $this->getUserDateID(), $this->getId() );
-		if ( $udtlf->getRecordCount() > 0 ) {
-			Debug::text(' Found Conflicting User Date Total Records, removing them before re-calc', __FILE__, __LINE__, __METHOD__,10);
-			foreach($udtlf as $udt_obj) {
-				$udt_obj->setDeleted(TRUE);
-				$udt_obj->Save();
-			}
-		}
-
-		$udtf = new UserDateTotalFactory();
-		$udtf->setUserDateID( $this->getUserDateID() );
-		$udtf->setPunchControlID( $this->getId() );
-		$udtf->setStatus( 20 ); //Worked
-		$udtf->setType( 10 ); //Total
-		$udtf->setBranch( $this->getBranch() );
-		$udtf->setDepartment( $this->getDepartment() );
-		$udtf->setTotalTime( $this->getTotalTime() );
-		$udtf->setEnableCalcSystemTotalTime( TRUE );
-		return $udtf->Save();
-
-		return TRUE;
-	}
-*/
-
 	function getEnableCalcSystemTotalTime() {
 		if ( isset($this->calc_system_total_time) ) {
 			return $this->calc_system_total_time;
@@ -901,7 +804,7 @@ class PunchControlFactory extends Factory {
 				if ( $jlf->getRecordCount() > 0 ) {
 					$j_obj = $jlf->getCurrent();
 
-					if ( $j_obj->getUserAllowAll() == FALSE AND is_array( $j_obj->getUser() ) AND !in_array( $this->getUserDateObject()->getUser(), $j_obj->getUser() ) ) {
+					if ( $j_obj->getUserAllowAll() == FALSE AND is_array( $j_obj->getUser() ) AND is_object( $this->getUserDateObject() ) AND !in_array( $this->getUserDateObject()->getUser(), $j_obj->getUser() ) ) {
 						$this->Validator->isTRUE(	'job',
 													FALSE,
 													TTi18n::gettext('Employee is not assigned to this job') );
@@ -963,7 +866,7 @@ class PunchControlFactory extends Factory {
 
 	function postSave() {
 		$this->removeCache( $this->getId() );
-		
+
 		//Do this regardless of if EnableCalcUserDateTotal is set.
 		Debug::text(' Old User Date ID: '. $this->getOldUserDateId() .' RAW: '. $this->tmp_data['old_user_date_id'], __FILE__, __LINE__, __METHOD__,10);
 		if ( $this->getOldUserDateId() !== FALSE ) {
