@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: Data.class.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 2453 $
+ * $Id: Data.class.php 2453 2009-03-20 16:34:04Z ipso $
+ * $Date: 2009-03-20 09:34:04 -0700 (Fri, 20 Mar 2009) $
  */
 
 /*
@@ -51,7 +51,7 @@ NOCHANGE-	'KS' => 'Kansas',		- http://www.ksrevenue.org/forms-btwh.htm
 DONE-	'KY' => 'Kentucky', 	- http://revenue.ky.gov/business/whtax.htm
 NOCHANGE-until July	'LA' => 'Louisiana',	- http://www.revenue.louisiana.gov/sections/publications/tm.asp
 DONE-	'ME' => 'Maine',		- http://www.state.me.us/revenue/forms/with/2009.htm -- Check each year.
-DONE-	'MD' => 'Maryland',		- http://business.marylandtaxes.com/taxinfo/withholding/default.asp
+DONE-	'MD' => 'Maryland',		- http://www.oregon.gov/DOR/BUS/withholding.shtml - http://business.marylandtaxes.com/taxinfo/withholding/default.asp
 NOCHANGE-	'MA' => 'Massachusetts' - http://www.mass.gov/?pageID=dorterminal&L=3&L0=Home&L1=Businesses&L2=Current+Tax+Year+Information&sid=Ador&b=terminalcontent&f=dor_business_buspubs&csid=Ador
 DONE-	'MI' => 'Michigan',		- http://www.michigan.gov/documents/treasury/446_2007_176836_7.pdf
 DONE-	'MN' => 'Minnesota',	- http://www.taxes.state.mn.us/taxes/withholding/index.shtml
@@ -154,6 +154,23 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 
 	*/
 	var $eic_options = array(
+								1238569200 => array( //01-Apr-09
+													10 => array(
+																array( 'income' => 8950,  'calculation_type' => 10, 'percent' => 20.40 ),
+																array( 'income' => 16420, 'calculation_type' => 20, 'amount' => 1826 ),
+																array( 'income' => 16420, 'calculation_type' => 30, 'amount' => 1826, 'percent' => 9.588  ),
+																),
+													20 => array(
+																array( 'income' => 8950,  'calculation_type' => 10, 'percent' => 20.40 ),
+																array( 'income' => 21420, 'calculation_type' => 20, 'amount' => 1826 ),
+																array( 'income' => 21420, 'calculation_type' => 30, 'amount' => 1826, 'percent' => 9.588  ),
+																),
+													30 => array(
+																array( 'income' => 4475, 'calculation_type' => 10, 'percent' => 20.40 ),
+																array( 'income' => 10710, 'calculation_type' => 20, 'amount' => 913 ),
+																array( 'income' => 10710, 'calculation_type' => 30, 'amount' => 913, 'percent' => 9.588  ),
+																),
+													),
 								1199174400 => array( //01-Jan-08
 													10 => array(
 																array( 'income' => 8580,  'calculation_type' => 10, 'percent' => 20.40 ),
@@ -363,14 +380,14 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 			$rate = $values['rate'];
 			$constant = $values['constant'];
 
-			Debug::text('Key: '. $key .' Value: '. $value .' Rate: '. $rate .' Constant: '. $constant .' Previous Value: '. $prev_value , __FILE__, __LINE__, __METHOD__,10);
+			//Debug::text('Key: '. $key .' Value: '. $value .' Rate: '. $rate .' Constant: '. $constant .' Previous Value: '. $prev_value , __FILE__, __LINE__, __METHOD__,10);
 
 			if ($income > $prev_value AND $income <= $value) {
-				Debug::text('Found Key: '. $key, __FILE__, __LINE__, __METHOD__,10);
+				//Debug::text('Found Key: '. $key, __FILE__, __LINE__, __METHOD__,10);
 
 				return $this->income_tax_rates[$type][$key];
 			} elseif ($i == $total_rates) {
-				Debug::text('Found Last Key: '. $key, __FILE__, __LINE__, __METHOD__,10);
+				//Debug::text('Found Last Key: '. $key, __FILE__, __LINE__, __METHOD__,10);
 				return $this->income_tax_rates[$type][$key];
 			}
 
@@ -408,13 +425,13 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 		foreach ($rates as $key => $values) {
 			$value = $values['income'];
 
-			Debug::text('Key: '. $key .' Income: '. $value , __FILE__, __LINE__, __METHOD__,10);
+			//Debug::text('Key: '. $key .' Income: '. $value , __FILE__, __LINE__, __METHOD__,10);
 
 			if ($income > $prev_value AND $income <= $value) {
-				Debug::text('Found Key: '. $key, __FILE__, __LINE__, __METHOD__,10);
+				//Debug::text('Found Key: '. $key, __FILE__, __LINE__, __METHOD__,10);
 				return $eic_options[$type][$key];
 			} elseif ($i == $total_rates) {
-				Debug::text('Found Last Key: '. $key, __FILE__, __LINE__, __METHOD__,10);
+				//Debug::text('Found Last Key: '. $key, __FILE__, __LINE__, __METHOD__,10);
 				return $eic_options[$type][$key];
 			}
 
