@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 1324 $
- * $Id: Requirements.php 1324 2007-10-19 18:44:48Z ipso $
- * $Date: 2007-10-19 11:44:48 -0700 (Fri, 19 Oct 2007) $
+ * $Revision: 2352 $
+ * $Id: Requirements.php 2352 2009-01-16 19:08:25Z ipso $
+ * $Date: 2009-01-16 11:08:25 -0800 (Fri, 16 Jan 2009) $
  */
 @ini_set('display_errors', true);
 
@@ -64,7 +64,6 @@ switch ($action) {
 
 		Redirect::Page( URLBuilder::getURL(NULL, 'install.php') );
 		break;
-
 	case 'next':
 		Debug::Text('Next', __FILE__, __LINE__, __METHOD__,10);
 		if ( $external_installer == 1 ) {
@@ -77,11 +76,15 @@ switch ($action) {
 		break;
 }
 
-$install_obj->checkAllRequirements();
-
 $handle = @fopen('http://www.timetrex.com/'.URLBuilder::getURL( array_merge( array('v' => $install_obj->getFullApplicationVersion(), 'page' => 'require'), $install_obj->getFailedRequirements() ), 'pre_install.php'), "r");
 @fclose($handle);
 
+$check_all_requirements = $install_obj->checkAllRequirements();
+if ( $external_installer == 1 AND $check_all_requirements == 0 AND $install_obj->checkTimeTrexVersion() == 0 ) {
+	//Using external installer and there is no missing requirements, automatically send to next page.
+	Redirect::Page( URLBuilder::getURL( array('external_installer' => $external_installer, 'action:next' => 'next' ), $_SERVER['SCRIPT_NAME']) );
+}
+
 $smarty->assign_by_ref('install_obj', $install_obj);
 $smarty->assign_by_ref('external_installer', $external_installer);
 $smarty->display('install/Requirements.tpl');
