@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: PayStubSummary.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 2338 $
+ * $Id: PayStubSummary.php 2338 2009-01-14 21:32:59Z ipso $
+ * $Date: 2009-01-14 13:32:59 -0800 (Wed, 14 Jan 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -199,7 +199,7 @@ switch ($action) {
 					$pslf = new PayStubListFactory();
 					//$pslf->getByUserIdAndCompanyIdAndPayPeriodId( $filter_data['user_ids'], $current_company->getId(), $filter_data['pay_period_ids']);
 					$pslf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
-					if ( $pslf->getRecordCount() > 0 ) {
+					if ( $pslf->getRecordCount() > 0 AND strlen($filter_data['export_type']) >= 3) {
 						$output = $pslf->exportPayStub( $pslf, $filter_data['export_type'] );
 
 						if ( Debug::getVerbosity() < 11 ) {
@@ -209,9 +209,16 @@ switch ($action) {
 								Misc::FileDownloadHeader('eft_'. str_replace(array('/',',',' '), '_', TTDate::getDate('DATE', time() ) ) .'.txt', 'application/text', strlen($output));
 							}
 
-							echo $output;
+							if ( $output != FALSE ) {
+								echo $output;
+							} else {
+								echo TTi18n::gettext('No data to export.') ."<br>\n";
+							}
 							exit;
 						}
+					} else {
+						echo TTi18n::gettext('No data to export or export format is invalid.') ."<br>\n";
+						exit;
 					}
 				} else {
 					//Get column headers
@@ -557,7 +564,7 @@ switch ($action) {
 		$filter_data['group_by_options'] = Misc::prependArray( array('0' => TTi18n::gettext('No Grouping')), $static_columns );
 
 		$psf = new PayStubFactory();
-		$filter_data['export_type_options'] = $psf->getOptions('export_type');
+		$filter_data['export_type_options'] = Misc::prependArray( array( 'csv' => TTi18n::gettext('CSV (Excel)') ), $psf->getOptions('export_type') );
 
 		$saved_report_options = $ugdlf->getByUserIdAndScriptArray( $current_user->getId(), $_SERVER['SCRIPT_NAME']);
 		$generic_data['saved_report_options'] = $saved_report_options;
