@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: T4Summary.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 2426 $
+ * $Id: T4Summary.php 2426 2009-02-18 22:39:19Z ipso $
+ * $Date: 2009-02-18 14:39:19 -0800 (Wed, 18 Feb 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -55,27 +55,34 @@ URLBuilder::setURL($_SERVER['SCRIPT_NAME'],
 												) );
 
 $static_columns = array(			'-1000-full_name' => TTi18n::gettext('Full Name'),
-											'-1010-title' => TTi18n::gettext('Title'),
-											'-1020-province' => TTi18n::gettext('Province'),
-											'-1030-country' => TTi18n::gettext('Country'),
-											'-1039-group' => TTi18n::gettext('Group'),
-											'-1040-default_branch' => TTi18n::gettext('Default Branch'),
-											'-1050-default_department' => TTi18n::gettext('Default Department'),
-											'-1060-sin' => TTi18n::gettext('SIN')
-											);
+									'-1010-title' => TTi18n::gettext('Title'),
+									'-1020-province' => TTi18n::gettext('Province'),
+									'-1030-country' => TTi18n::gettext('Country'),
+									'-1039-group' => TTi18n::gettext('Group'),
+									'-1040-default_branch' => TTi18n::gettext('Default Branch'),
+									'-1050-default_department' => TTi18n::gettext('Default Department'),
+									'-1060-sin' => TTi18n::gettext('SIN')
+									);
 
 $non_static_columns = array(		'-1100-income' => TTi18n::gettext('Income (14)'),
-											'-1110-income_tax' => TTi18n::gettext('Income Tax (22)'),
-											'-1120-employee_cpp' => TTi18n::gettext('Employee CPP (16)'),
-											'-1125-ei_earnings' => TTi18n::gettext('EI Insurable Earnings (24)'),
-											'-1130-employee_ei' => TTi18n::gettext('Employee EI (18)'),
-											'-1140-union_dues' => TTi18n::gettext('Union Dues (44)'),
-											'-1150-employer_cpp' => TTi18n::gettext('Employer CPP'),
-											'-1160-employer_ei' => TTi18n::gettext('Employer EI'),
-											'-1200-other_box_0' => TTi18n::gettext('Other Box 1'),
-											'-1210-other_box_1' => TTi18n::gettext('Other Box 2'),
-											'-1220-other_box_2' => TTi18n::gettext('Other Box 3'),
-											);
+									'-1110-income_tax' => TTi18n::gettext('Income Tax (22)'),
+									'-1120-employee_cpp' => TTi18n::gettext('Employee CPP (16)'),
+									'-1125-ei_earnings' => TTi18n::gettext('EI Insurable Earnings (24)'),
+									'-1126-cpp_earnings' => TTi18n::gettext('CPP Pensionable Earnings (26)'),
+									'-1130-employee_ei' => TTi18n::gettext('Employee EI (18)'),
+									'-1140-union_dues' => TTi18n::gettext('Union Dues (44)'),
+									'-1150-employer_cpp' => TTi18n::gettext('Employer CPP'),
+									'-1160-employer_ei' => TTi18n::gettext('Employer EI'),
+									'-1170-rpp' => TTi18n::gettext('RPP Contributions (20)'),
+									'-1180-charity' => TTi18n::gettext('Charity Donations (46)'),
+									'-1190-pension_adjustment' => TTi18n::gettext('Pension Adjustment (52)'),
+									'-1200-other_box_0' => TTi18n::gettext('Other Box 1'),
+									'-1210-other_box_1' => TTi18n::gettext('Other Box 2'),
+									'-1220-other_box_2' => TTi18n::gettext('Other Box 3'),
+									'-1220-other_box_3' => TTi18n::gettext('Other Box 4'),
+									'-1220-other_box_4' => TTi18n::gettext('Other Box 5'),
+									'-1220-other_box_5' => TTi18n::gettext('Other Box 6'),
+									);
 
 $pseallf = new PayStubEntryAccountLinkListFactory();
 $pseallf->getByCompanyId( $current_company->getId() );
@@ -86,15 +93,22 @@ if ( $pseallf->getRecordCount() > 0 ) {
 $column_ps_entry_name_map = array(
 								'income' => @$setup_data['income_psea_ids'], //Gross Pay
 								'income_tax' => @$setup_data['tax_psea_ids'],
-								'employee_cpp' => array($setup_data['employee_cpp_psea_id']),
-								'employee_ei' => array($setup_data['employee_ei_psea_id']),
+								'employee_cpp' => @$setup_data['employee_cpp_psea_id'],
+								'employee_ei' => @$setup_data['employee_ei_psea_id'],
 								'ei_earnings' => @$setup_data['ei_earnings_psea_ids'],
-								'union_dues' => array($setup_data['union_dues_psea_id']),
-								'employer_cpp' => array($setup_data['employer_cpp_psea_id']),
-								'employer_ei' => array($setup_data['employer_ei_psea_id']),
+								'cpp_earnings' => @$setup_data['cpp_earnings_psea_ids'],
+								'union_dues' => @$setup_data['union_dues_psea_id'],
+								'employer_cpp' => @$setup_data['employer_cpp_psea_id'],
+								'employer_ei' => @$setup_data['employer_ei_psea_id'],
+								'rpp' => @$setup_data['rpp_psea_ids'],
+								'charity' => @$setup_data['charity_psea_ids'],
+								'pension_adjustment' => @$setup_data['pension_adjustment_psea_ids'],
 								'other_box_0' => @$setup_data['other_box'][0]['psea_ids'],
 								'other_box_1' => @$setup_data['other_box'][1]['psea_ids'],
 								'other_box_2' => @$setup_data['other_box'][2]['psea_ids'],
+								'other_box_3' => @$setup_data['other_box'][3]['psea_ids'],
+								'other_box_4' => @$setup_data['other_box'][4]['psea_ids'],
+								'other_box_5' => @$setup_data['other_box'][5]['psea_ids'],
 								);
 
 $columns = Misc::prependArray( $static_columns, $non_static_columns);
@@ -115,7 +129,7 @@ switch ($action) {
 		//Debug::setVerbosity(11);
 
 		Debug::Text('Submit!: '. $action, __FILE__, __LINE__, __METHOD__,10);
-		Debug::Arr($filter_data, 'aFilter Data', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data, 'aFilter Data', __FILE__, __LINE__, __METHOD__,10);
 
 		//Save report setup data
 		$ugdlf->getByCompanyIdAndScriptAndDefault( $current_company->getId(), $_SERVER['SCRIPT_NAME'] );
@@ -145,21 +159,8 @@ switch ($action) {
 					Debug::Text(' Year: '. TTDate::getDate('DATE+TIME', $year_epoch) , __FILE__, __LINE__, __METHOD__,10);
 				}
 
-				//This must go by PAYSTUB transaction date, not PAY PERIOD transaction date.
-				//To handle cases where a pay stub is paid earlier then the pay period transaction date
-				//due to dismissal, and the transaction date happens to fall before the new year.
-/*
-				$pplf->getByCompanyIdAndTransactionStartDateAndTransactionEndDate( $current_company->getId(), TTDate::getBeginYearEpoch($year_epoch), TTDate::getEndYearEpoch($year_epoch) );
-				if ( $pplf->getRecordCount() > 0 ) {
-					foreach($pplf as $pp_obj) {
-						$pay_period_ids[] = $pp_obj->getID();
-					}
-				}
-*/
 				$pself = new PayStubEntryListFactory();
 				$pself->getReportByCompanyIdAndUserIdAndTransactionStartDateAndTransactionEndDate($current_company->getId(), $filter_data['user_ids'], TTDate::getBeginYearEpoch($year_epoch), TTDate::getEndYearEpoch($year_epoch) );
-				//$pself->getReportByCompanyIdAndUserIdAndPayPeriodId( $current_company->getId(), $filter_data['user_ids'], $pay_period_ids );
-
 
 				$report_columns = $static_columns;
 
@@ -212,7 +213,7 @@ switch ($action) {
 						$x++;
 					}
 				}
-				//var_dump($rows);
+				//var_dump($tmp_rows);
 
 				//Skip grouping if they are displaying T4's
 				if ( $action != 'display_t4s' AND isset($filter_data['primary_group_by']) AND $filter_data['primary_group_by'] != '0' ) {
@@ -262,134 +263,50 @@ switch ($action) {
 		if ( $action == 'display_t4s' ) {
 			Debug::Text('Generating PDF: ', __FILE__, __LINE__, __METHOD__,10);
 
+			$last_row = count($rows)-1;
+			$total_row = $last_row+1;
+
 			//Get company information
 			$clf = new CompanyListFactory();
 			$company_obj = $clf->getById( $current_company->getId() )->getCurrent();
 
-			$border = 0;
+			//Debug::setVerbosity(11);
+			$t4 = new T4;
+			if ( isset($filter_data['include_t4_back']) AND $filter_data['include_t4_back'] == 1 ) {
+				$t4->setShowInstructionPage(TRUE);
+			}
+			//$t4->setShowBackGround(FALSE);
+			$t4->setShowBorder(FALSE);
+			//$t4->setXOffset(10);
+			//$t4->setYOffset(10);
 
-			$pdf= new fpdi();
+			$t4->setType( $filter_data['type'] );
+			$t4->setYear( $filter_data['year'] );
+			$t4->setBusinessNumber( $company_obj->getBusinessNumber() );
 
-			//Import original Gov't supplied PDF.
-			$pagecount = $pdf->setSourceFile(Environment::getBasePath().'interface'. DIRECTORY_SEPARATOR .'forms'. DIRECTORY_SEPARATOR .'ca'. DIRECTORY_SEPARATOR .'tax'. DIRECTORY_SEPARATOR .'t4flat-05b.pdf');
-			$tplidx = $pdf->ImportPage(1);
-			$tplidx_back = $pdf->ImportPage(2);
+			$t4->setCompanyName( $company_obj->getName() );
+			$t4->setCompanyAddress1( $company_obj->getAddress1() );
+			$t4->setCompanyAddress2( $company_obj->getAddress2() );
+			$t4->setCompanyCity( $company_obj->getCity() );
+			$t4->setCompanyProvince( $company_obj->getProvince() );
+			$t4->setCompanyPostalCode( $company_obj->getPostalCode() );
 
-			$pdf->setMargins(5,5,5,5);
-			$pdf->SetAutoPageBreak(FALSE);
-			$pdf->SetFont('freeserif','',10);
+			$t4sum = new T4Summary();
+			$t4sum->setTotalT4s( count($rows)-1 );
+			$t4sum->setEmploymentIncome( $rows[$last_row]['income'] );
+			$t4sum->setIncomeTax( $rows[$last_row]['income_tax'] );
+			$t4sum->setEmployeeCPP( $rows[$last_row]['employee_cpp'] );
+			$t4sum->setEmployeeEI($rows[$last_row]['employee_ei'] );
+			$t4sum->setEmployerCPP(  $rows[$last_row]['employer_cpp'] );
+			$t4sum->setEmployerEI( $rows[$last_row]['employer_ei'] );
+			$t4sum->setEmployeeRPP( $rows[$last_row]['rpp'] );
+			$t4sum->setPensionAdjustment( $rows[$last_row]['pension_adjustment'] );
+
+			$total_deductions = Misc::MoneyFormat( $rows[$last_row]['employee_cpp'] + $rows[$last_row]['employer_cpp'] + $rows[$last_row]['employee_ei'] + $rows[$last_row]['employer_ei'] + $rows[$last_row]['income_tax'], FALSE );
+			$t4sum->setTotalDeductions( $total_deductions );
+			$t4->addT4Summary( $t4sum );
 
 			$i=0;
-			$last_row = count($rows)-1;
-
-			$total_row = $last_row+1;
-			/*
-
-				Fill out summary form.
-
-			*/
-
-			//Import original Gov't supplied PDF.
-			$pagecount = $pdf->setSourceFile(Environment::getBasePath().'interface/forms/ca/tax/t4-sum-05b.pdf');
-			$tplidx_summary = $pdf->ImportPage(1);
-
-			$pdf->AddPage();
-			$pdf->useTemplate($tplidx_summary,0,0);
-
-			//Total T4's
-			$pdf->setXY(79,16);
-			$pdf->Cell(10,5, substr($filter_data['year'],2,2) , $border, 0, 'C');
-
-			//Business Number
-			$pdf->setXY(102,29);
-			$pdf->Cell(65,5,$company_obj->getBusinessNumber(), $border, 0, 'L');
-
-			//Employer Info
-			$pdf->setXY(102,40);
-			$pdf->Cell(65,5,$company_obj->getName(), $border, 0, 'L');
-
-			$pdf->setXY(102,45);
-			$pdf->Cell(65,5,$company_obj->getAddress1().' '.$company_obj->getAddress2(), $border, 0, 'L');
-
-			$pdf->setXY(102,50);
-			$pdf->Cell(65,5,$company_obj->getCity().', '.$company_obj->getProvince(), $border, 0, 'L');
-
-			$postal_code_a = substr($company_obj->getPostalCode(), 0, 3);
-			$postal_code_b = substr($company_obj->getPostalCode(), 3, 6);
-
-			$pdf->setXY(102,55);
-			$pdf->Cell(20,5,$postal_code_a.' '. $postal_code_b, $border, 0, 'L');
-
-			//Total T4 slips
-			$pdf->setXY(25,74.5);
-			$pdf->Cell(20,5,$last_row, $border, 0, 'L');
-
-			//Income
-			if ( $rows[$last_row]['income'] > 0 ) {
-				$pdf->setXY(55,87.5);
-				$pdf->Cell(20,5,Misc::getBeforeDecimal( $rows[$last_row]['income'] ), $border, 0, 'R');
-				$pdf->setXY(75,87.5);
-				$pdf->Cell(10,5,Misc::getAfterDecimal( $rows[$last_row]['income'] ), $border, 0, 'C');
-			}
-
-			//Employee CPP
-			if ( $rows[$last_row]['employee_cpp'] > 0 ) {
-				$pdf->setXY(121,74.5);
-				$pdf->Cell(20,5,Misc::getBeforeDecimal( $rows[$last_row]['employee_cpp'] ), $border, 0, 'R');
-				$pdf->setXY(141,74.5);
-				$pdf->Cell(10,5,Misc::getAfterDecimal( $rows[$last_row]['employee_cpp'] ), $border, 0, 'C');
-			}
-
-			//Employers CPP
-			if ( $rows[$last_row]['employer_cpp'] > 0 ) {
-				$pdf->setXY(121,87.5);
-				$pdf->Cell(20,5,Misc::getBeforeDecimal( $rows[$last_row]['employer_cpp'] ), $border, 0, 'R');
-				$pdf->setXY(141,87.5);
-				$pdf->Cell(10,5,Misc::getAfterDecimal( $rows[$last_row]['employer_cpp'] ), $border, 0, 'C');
-			}
-
-			//Employees EI
-			if ( $rows[$last_row]['employee_ei'] > 0 ) {
-				$pdf->setXY(121,100);
-				$pdf->Cell(20,5,Misc::getBeforeDecimal( $rows[$last_row]['employee_ei'] ), $border, 0, 'R');
-				$pdf->setXY(141,100);
-				$pdf->Cell(10,5,Misc::getAfterDecimal( $rows[$last_row]['employee_ei'] ), $border, 0, 'C');
-			}
-
-			//Employers EI
-			if ( $rows[$last_row]['employer_ei'] > 0 ) {
-				$pdf->setXY(121,113);
-				$pdf->Cell(20,5,Misc::getBeforeDecimal( $rows[$last_row]['employer_ei'] ), $border, 0, 'R');
-				$pdf->setXY(141,113);
-				$pdf->Cell(10,5,Misc::getAfterDecimal( $rows[$last_row]['employer_ei'] ), $border, 0, 'C');
-			}
-
-			//Income Tax
-			if ( $rows[$last_row]['income_tax'] > 0 ) {
-				$pdf->setXY(121,126);
-				$pdf->Cell(20,5,Misc::getBeforeDecimal( $rows[$last_row]['income_tax'] ), $border, 0, 'R');
-				$pdf->setXY(141,126);
-				$pdf->Cell(10,5,Misc::getAfterDecimal( $rows[$last_row]['income_tax'] ), $border, 0, 'C');
-			}
-
-			//Total Deductons
-			$total_deductions = Misc::MoneyFormat( $rows[$last_row]['employee_cpp'] + $rows[$last_row]['employer_cpp'] + $rows[$last_row]['employee_ei'] + $rows[$last_row]['employer_ei'] + $rows[$last_row]['income_tax'], FALSE );
-			if ( $total_deductions > 0 ) {
-				$pdf->setXY(121,138);
-				$pdf->Cell(20,5,Misc::getBeforeDecimal( $total_deductions ), $border, 0, 'R');
-				$pdf->setXY(141,138);
-				$pdf->Cell(10,5,Misc::getAfterDecimal( $total_deductions ), $border, 0, 'C');
-			}
-/*
-			//Remittance
-			if ( $total_deductions > 0 ) {
-				$pdf->setXY(121,151);
-				$pdf->Cell(20,5,Misc::getBeforeDecimal( $total_deductions ), $border, 0, 'R');
-				$pdf->setXY(141,151);
-				$pdf->Cell(10,5,Misc::getAfterDecimal( $total_deductions ), $border, 0, 'C');
-			}
-*/
-
 			foreach($rows as $row) {
 				if ( $i == $last_row ) {
 					continue;
@@ -398,60 +315,18 @@ switch ($action) {
 				$ulf = new UserListFactory();
 				$user_obj = $ulf->getById( $row['user_id'] )->getCurrent();
 
-				$pdf->AddPage();
-				$pdf->useTemplate($tplidx,0,0);
 
-				//Use the original PDF instead
-				//$pdf->Image(Environment::getBasePath().'interface/images/t4flat.jpg',0,0,210,300);
-				//$pdf->Image(Environment::getBasePath().'interface/images/t4flat.png',0,0);
-
-				$bottom_offset = 139;
-
-				//Year
-				$pdf->setXY(127,13.5);
-				$pdf->Cell(19,5,$filter_data['year'], $border, 0, 'C');
-
-				$pdf->setXY(127,13.5+$bottom_offset);
-				$pdf->Cell(19,5,$filter_data['year'], $border, 0, 'C');
-
-				//Employer Info
-				$pdf->setXY(18,10);
-				$pdf->Cell(65,5,$company_obj->getName(), $border, 0, 'L');
-				$pdf->setXY(18,10+$bottom_offset);
-				$pdf->Cell(65,5,$company_obj->getName(), $border, 0, 'L');
-
-				$pdf->setXY(18,15);
-				$pdf->Cell(65,5,$company_obj->getAddress1().' '.$company_obj->getAddress2(), $border, 0, 'L');
-				$pdf->setXY(18,15+$bottom_offset);
-				$pdf->Cell(65,5,$company_obj->getAddress1().' '.$company_obj->getAddress2(), $border, 0, 'L');
-
-				$pdf->setXY(18,20);
-				$pdf->Cell(65,5,$company_obj->getCity().', '.$company_obj->getProvince(), $border, 0, 'L');
-				$pdf->setXY(18,20+$bottom_offset);
-				$pdf->Cell(65,5,$company_obj->getCity().', '.$company_obj->getProvince(), $border, 0, 'L');
-
-
-				$postal_code_a = substr($company_obj->getPostalCode(), 0, 3);
-				$postal_code_b = substr($company_obj->getPostalCode(), 3, 6);
-
-				$pdf->setXY(18,25);
-				$pdf->Cell(20,5,$postal_code_a.' '. $postal_code_b, $border, 0, 'L');
-				$pdf->setXY(18,25+$bottom_offset);
-				$pdf->Cell(20,5,$postal_code_a.' '. $postal_code_b, $border, 0, 'L');
-
-				//Business Number
-				$pdf->setXY(21,39);
-				$pdf->Cell(35,5,$company_obj->getBusinessNumber(), $border, 0, 'L');
-				$pdf->setXY(21,39+$bottom_offset);
-				$pdf->Cell(35,5,$company_obj->getBusinessNumber(), $border, 0, 'L');
-
-				//SIN
-				$pdf->setXY(21,51.5);
-				$pdf->Cell(35,5,$row['sin'], $border, 0, 'L');
-				$pdf->setXY(21,51.5+$bottom_offset);
-				$pdf->Cell(35,5,$row['sin'], $border, 0, 'L');
-
-				//Excemptions
+				$t4ee = new T4Employee();
+				$t4ee->setSin( $row['sin'] );
+				$t4ee->setFirstName( $user_obj->getFirstName() );
+				$t4ee->setMiddleName( $user_obj->getMiddleName() );
+				$t4ee->setLastName( $user_obj->getLastName()  );
+				$t4ee->setAddress1( $user_obj->getAddress1() );
+				$t4ee->setAddress2( $user_obj->getAddress2() );
+				$t4ee->setCity( $user_obj->getCity() );
+				$t4ee->setProvince( $user_obj->getProvince() );
+				$t4ee->setPostalCode( $user_obj->getPostalCode() );
+				//$t4ee->setEmployementCode( );
 
 				//Get User Tax / Deductions by Pay Stub Account.
 				$udlf = new UserDeductionListFactory();
@@ -459,206 +334,64 @@ switch ($action) {
 				if ( $setup_data['employee_cpp_psea_id'] != 0
 						AND $udlf->getRecordCount() == 0 ) {
 					Debug::Text('CPP Exempt!', __FILE__, __LINE__, __METHOD__,10);
-					$pdf->setXY(74,51.5);
-					$pdf->Cell(5,5,'X', $border, 0, 'C');
-					$pdf->setXY(74,51.5+$bottom_offset);
-					$pdf->Cell(5,5,'X', $border, 0, 'C');
+					$t4ee->setExemptCPP( TRUE );
 				}
 
 				$udlf->getByUserIdAndPayStubEntryAccountID( $user_obj->getId(), $setup_data['employee_ei_psea_id'] );
 				if ( $setup_data['employee_ei_psea_id'] != 0
 						AND $udlf->getRecordCount() == 0 ) {
 					Debug::Text('EI Exempt!', __FILE__, __LINE__, __METHOD__,10);
-					$pdf->setXY(83,51.5);
-					$pdf->Cell(5,5,'X', $border, 0, 'C');
-					$pdf->setXY(83,51.5+$bottom_offset);
-					$pdf->Cell(5,5,'X', $border, 0, 'C');
+					$t4ee->setExemptEI( TRUE );
 				}
 
-				//Employee Info
-				$pdf->setXY(20,70);
-				$pdf->Cell(55,5,strtoupper( $user_obj->getLastName() ), $border, 0, 'L');
-				$pdf->setXY(20,70+$bottom_offset);
-				$pdf->Cell(55,5,strtoupper( $user_obj->getLastName() ), $border, 0, 'L');
+				$t4ee->setEmploymentIncome( $row['income'] );
+				$t4ee->setIncomeTax( $row['income_tax'] );
+				$t4ee->setEmployeeCPP( $row['employee_cpp'] );
+				$t4ee->setEIEarnings( $row['ei_earnings'] );
+				$t4ee->setCPPEarnings( $row['cpp_earnings'] );
+				$t4ee->setEmployeeEI( $row['employee_ei'] );
+				$t4ee->setUnionDues( $row['union_dues']  );
+				$t4ee->setEmployeeRPP( $row['rpp'] );
+				$t4ee->setCharityDonations( $row['charity'] );
+				$t4ee->setPensionAdjustment( $row['pension_adjustment'] );
 
-				$pdf->setXY(78,70);
-				$pdf->Cell(25,5,$user_obj->getFirstName(), $border, 0, 'L');
-				$pdf->setXY(78,70+$bottom_offset);
-				$pdf->Cell(25,5,$user_obj->getFirstName(), $border, 0, 'L');
-
-				$pdf->setXY(108,70);
-				$pdf->Cell(8,5,substr( $user_obj->getMiddleName(),0,1), $border, 0, 'R');
-				$pdf->setXY(108,70+$bottom_offset);
-				$pdf->Cell(8,5,substr( $user_obj->getMiddleName(),0,1), $border, 0, 'R');
-
-				$pdf->setXY(20,77);
-				$pdf->Cell(75,5,$user_obj->getAddress1().' '.$user_obj->getAddress2(), $border, 0, 'L');
-				$pdf->setXY(20,77+$bottom_offset);
-				$pdf->Cell(75,5,$user_obj->getAddress1().' '.$user_obj->getAddress2(), $border, 0, 'L');
-
-				$pdf->setXY(20,82);
-				$pdf->Cell(75,5,$user_obj->getCity().', '.$user_obj->getProvince(), $border, 0, 'L');
-				$pdf->setXY(20,82+$bottom_offset);
-				$pdf->Cell(75,5,$user_obj->getCity().', '.$user_obj->getProvince(), $border, 0, 'L');
-
-				$pdf->setXY(20,87);
-				$pdf->Cell(75,5,$user_obj->getPostalCode(), $border, 0, 'L');
-				$pdf->setXY(20,87+$bottom_offset);
-				$pdf->Cell(75,5,$user_obj->getPostalCode(), $border, 0, 'L');
-
-				$pdf->setXY(107,39);
-				$pdf->Cell(10,5, $user_obj->getProvince(), $border, 0, 'C');
-				$pdf->setXY(107,39+$bottom_offset);
-				$pdf->Cell(10,5, $user_obj->getProvince(), $border, 0, 'C');
-
-				//Earnings
-				$pdf->setXY(132,26.5);
-				$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['income'] ), $border, 0, 'R');
-				$pdf->setXY(132,26.5+$bottom_offset);
-				$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['income'] ), $border, 0, 'R');
-
-				$pdf->setXY(153,26.5);
-				$pdf->Cell(10,5,Misc::getAfterDecimal( $row['income'] ), $border, 0, 'C');
-				$pdf->setXY(153,26.5+$bottom_offset);
-				$pdf->Cell(10,5,Misc::getAfterDecimal( $row['income'] ), $border, 0, 'C');
-
-				//Income Tax
-				if ( $row['income_tax'] > 0 ) {
-					$pdf->setXY(178,26.5);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['income_tax'] ), $border, 0, 'R');
-					$pdf->setXY(178,26.5+$bottom_offset);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['income_tax'] ), $border, 0, 'R');
-
-					$pdf->setXY(199,26.5);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['income_tax'] ), $border, 0, 'C');
-					$pdf->setXY(199,26.5+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['income_tax'] ), $border, 0, 'C');
-
-				}
-
-				//CPP
-				if ( $row['employee_cpp'] > 0 ) {
-					$pdf->setXY(132,39);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['employee_cpp'] ), $border, 0, 'R');
-					$pdf->setXY(132,39+$bottom_offset);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['employee_cpp'] ), $border, 0, 'R');
-
-					$pdf->setXY(153,39);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['employee_cpp'] ), $border, 0, 'C');
-					$pdf->setXY(153,39+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['employee_cpp'] ), $border, 0, 'C');
-
-				}
-
-				//EI Earnings
-				if ( $row['ei_earnings'] > 0 ) {
-					$pdf->setXY(178,39);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['ei_earnings'] ), $border, 0, 'R');
-					$pdf->setXY(178,39+$bottom_offset);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['ei_earnings'] ), $border, 0, 'R');
-
-					$pdf->setXY(199,39);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['ei_earnings'] ), $border, 0, 'C');
-					$pdf->setXY(199,39+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['ei_earnings'] ), $border, 0, 'C');
-				}
-
-				//EI
-				if ( $row['employee_ei'] > 0 ) {
-					$pdf->setXY(132,64.5);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['employee_ei'] ), $border, 0, 'R');
-					$pdf->setXY(132,64.5+$bottom_offset);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['employee_ei'] ), $border, 0, 'R');
-
-					$pdf->setXY(153,64.5);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['employee_ei'] ), $border, 0, 'C');
-					$pdf->setXY(153,64.5+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['employee_ei'] ), $border, 0, 'C');
-
-				}
-
-				//Union Dues
-				if ( $row['union_dues'] > 0 ) {
-					$pdf->setXY(178,64.5);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['union_dues'] ), $border, 0, 'R');
-					$pdf->setXY(178,64.5+$bottom_offset);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['union_dues'] ), $border, 0, 'R');
-
-					$pdf->setXY(199,64.5);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['union_dues'] ), $border, 0, 'C');
-					$pdf->setXY(199,64.5+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['union_dues'] ), $border, 0, 'C');
-				}
-
-				//Other Box(s)
 				if ( $row['other_box_0'] > 0 AND isset($setup_data['other_box'][0]['box']) AND $setup_data['other_box'][0]['box'] !='') {
-					$pdf->setXY(40,115);
-					$pdf->Cell(10,5,Misc::getBeforeDecimal( $setup_data['other_box'][0]['box'] ), $border, 0, 'C');
-					$pdf->setXY(40,114+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getBeforeDecimal( $setup_data['other_box'][0]['box'] ), $border, 0, 'C');
-
-					$pdf->setXY(63,115);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['other_box_0'] ), $border, 0, 'R');
-					$pdf->setXY(63,114+$bottom_offset);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['other_box_0'] ), $border, 0, 'R');
-
-					$pdf->setXY(83,115);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['other_box_0'] ), $border, 0, 'C');
-					$pdf->setXY(83,114+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['other_box_0'] ), $border, 0, 'C');
+					$t4ee->setOtherBox1Code( $setup_data['other_box'][0]['box'] );
+					$t4ee->setOtherBox1( $row['other_box_0'] );
 				}
 
 				if ( $row['other_box_1'] > 0 AND isset($setup_data['other_box'][1]['box']) AND $setup_data['other_box'][1]['box'] !='') {
-					$pdf->setXY(98,115);
-					$pdf->Cell(10,5,Misc::getBeforeDecimal( $setup_data['other_box'][1]['box'] ), $border, 0, 'C');
-					$pdf->setXY(98,114+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getBeforeDecimal( $setup_data['other_box'][1]['box'] ), $border, 0, 'C');
-
-					$pdf->setXY(120,115);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['other_box_1'] ), $border, 0, 'R');
-					$pdf->setXY(120,114+$bottom_offset);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['other_box_1'] ), $border, 0, 'R');
-
-					$pdf->setXY(141,115);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['other_box_1'] ), $border, 0, 'C');
-					$pdf->setXY(141,114+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['other_box_1'] ), $border, 0, 'C');
+					$t4ee->setOtherBox2Code( $setup_data['other_box'][1]['box'] );
+					$t4ee->setOtherBox2( $row['other_box_1'] );
 				}
 
 				if ( $row['other_box_2'] > 0 AND isset($setup_data['other_box'][2]['box']) AND $setup_data['other_box'][2]['box'] !='') {
-					$pdf->setXY(155,115);
-					$pdf->Cell(10,5,Misc::getBeforeDecimal( $setup_data['other_box'][2]['box'] ), $border, 0, 'C');
-					$pdf->setXY(155,114+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getBeforeDecimal( $setup_data['other_box'][2]['box'] ), $border, 0, 'C');
-
-					$pdf->setXY(177,115);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['other_box_2'] ), $border, 0, 'R');
-					$pdf->setXY(177,114+$bottom_offset);
-					$pdf->Cell(20,5,Misc::getBeforeDecimal( $row['other_box_2'] ), $border, 0, 'R');
-
-					$pdf->setXY(198,115);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['other_box_2'] ), $border, 0, 'C');
-					$pdf->setXY(198,114+$bottom_offset);
-					$pdf->Cell(10,5,Misc::getAfterDecimal( $row['other_box_2'] ), $border, 0, 'C');
+					$t4ee->setOtherBox3Code( $setup_data['other_box'][2]['box'] );
+					$t4ee->setOtherBox3( $row['other_box_2'] );
 				}
 
-				if ( isset($filter_data['include_t4_back']) AND $filter_data['include_t4_back'] == 1 ) {
-					$pdf->AddPage();
-					$pdf->useTemplate($tplidx_back,0,0);
+				if ( $row['other_box_3'] > 0 AND isset($setup_data['other_box'][3]['box']) AND $setup_data['other_box'][3]['box'] !='') {
+					$t4ee->setOtherBox4Code( $setup_data['other_box'][3]['box'] );
+					$t4ee->setOtherBox4( $row['other_box_3'] );
 				}
 
+				if ( $row['other_box_4'] > 0 AND isset($setup_data['other_box'][4]['box']) AND $setup_data['other_box'][4]['box'] !='') {
+					$t4ee->setOtherBox5Code( $setup_data['other_box'][4]['box'] );
+					$t4ee->setOtherBox5( $row['other_box_4'] );
+				}
+				if ( $row['other_box_5'] > 0 AND isset($setup_data['other_box'][5]['box']) AND $setup_data['other_box'][5]['box'] !='') {
+					$t4ee->setOtherBox6Code( $setup_data['other_box'][5]['box'] );
+					$t4ee->setOtherBox6( $row['other_box_5'] );
+				}
+				$t4->addT4Employee( $t4ee );
+
 				$i++;
 			}
 
+			$t4->compileT4Summary();
+			$t4->compileT4();
 
-			//Finish off PDF
-			$output = $pdf->Output('','S');
-
-			Misc::FileDownloadHeader('t4summary.pdf', 'application/pdf', strlen($output));
-			echo $output;
-
-			exit;
-
+			$t4->displayPDF();
 		} else {
 			Debug::Text('NOT Generating PDF: ', __FILE__, __LINE__, __METHOD__,10);
 		}
@@ -783,6 +516,7 @@ switch ($action) {
 		$filter_data['selected_column_options'] = Misc::arrayIntersectByKey( (array)$filter_data['column_ids'], $columns );
 
 		$filter_data['year_options'] = $year_options;
+		$filter_data['type_options'] = array('government' => TTi18n::gettext('Government (Multiple Employees/Page)'), 'employee' => TTi18n::gettext('Employee (One Employee/Page)') );
 
 		//Get primary/secondary order list
 		$filter_data['sort_options'] = $columns;
