@@ -21,9 +21,9 @@
  *
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: TimesheetDetail.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 2570 $
+ * $Id: TimesheetDetail.php 2570 2009-05-28 21:29:33Z ipso $
+ * $Date: 2009-05-28 14:29:33 -0700 (Thu, 28 May 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -1222,15 +1222,9 @@ switch ($action) {
 				//Flatten array for exporting.
 				foreach( $rows as $row ) {
 					if ( is_array($row['data']) ) {
-						//Filter out the total rows for each employee.
-						$max_data_rows = count($row['data']);
-						$x=1;
 						foreach( $row['data'] as $sub_row ) {
-							if ( $x < $max_data_rows ) {
-								unset($row['data']);
-								$tmp_rows[] = array_merge($row, $sub_row);
-							}
-							$x++;
+							unset($row['data']);
+							$tmp_rows[] = array_merge($row, $sub_row);
 						}
 					}
 				}
